# -*- encoding: utf-8 -*-
"""
@文件        :spider.py
@说明        :
@时间        :2024/11/25 20:01:51
@作者        :Zack
@版本        :1.0
"""
from dataclasses import dataclass

from gmscaffold.base.dataclass import BaseData


@dataclass
class SpiderData(BaseData):
    """ """
