# -*- encoding: utf-8 -*-
"""
@文件        :signal.py
@说明        :
@时间        :2024/11/25 11:35:42
@作者        :Zack
@版本        :1.0
"""

create_spider_project = object()
remove_spider_project = object()

create_web_project = object()
create_web_app = object()
remove_web_project = object()
remove_web_app = object()

create_gmapp_project = object()
remove_gmapp_project = object()

OPEN_CONNECT = 1
CLOSE_CONNECT = 0
