# -*- encoding: utf-8 -*-
"""
@文件        :__main__.py
@说明        :
@时间        :2024/11/25 11:55:11
@作者        :Zack
@版本        :1.0
"""
from gmscaffold.cmdline import execute

if __name__ == "__main__":
    execute()
